@@ -3,7 +3,7 @@
 
 '''A simple GUI for OpenPIV.'''
 
-__version__ = '0.2.6'
+__version__ = '0.2.9'
 
 __licence__ = '''
 This program is free software: you can redistribute it and/or modify
@@ -31,10 +31,12 @@ import tkinter.ttk as ttk
 import tkinter.messagebox as messagebox
 import webbrowser
 import shutil
+import threading
 
 from datetime import datetime
 
 import numpy as np
+import pandas as pd
 import openpiv.tools as piv_tls
 import matplotlib.pyplot as plt
 
@@ -50,7 +52,7 @@ from openpivgui.MultiProcessing import MultiProcessing
 from openpivgui.PostProcessing import PostProcessing
 
 from openpivgui.open_piv_gui_tools import str2list, str2dict, get_dim
-from openpivgui.vec_plot import vector, histogram, scatter, profiles
+from openpivgui.vec_plot import vector, histogram, scatter, profiles, pandas_plot
 
 class OpenPivGui(tk.Tk):
     '''Simple OpenPIV GUI
@@ -104,6 +106,11 @@ class OpenPivGui(tk.Tk):
         self.log(text = 'OpenPivGui version: ' + self.VERSION)
 
     def start_processing(self):
+        '''Wrapper function to start processing in a separate thread.'''
+        processing_thread = threading.Thread(target=self.processing)
+        processing_thread.start()
+        
+    def processing(self):
         '''Start the processing chain.
         
         This is the place to implement additional function calls.
@@ -187,8 +194,10 @@ class OpenPivGui(tk.Tk):
     def __init_fig_canvas(self, mother_frame):
         '''Creates a plotting area for matplotlib.
 
-        Args:
-            mother_frame (ttk.Frame): A frame to place the canvas in.
+        Parameters
+        ----------
+        mother_frame : ttk.Frame
+            A frame to place the canvas in.
         '''
         self.fig = Fig()
         self.fig_frame = ttk.Frame(mother_frame)
@@ -224,11 +233,7 @@ class OpenPivGui(tk.Tk):
                           self.fig_toolbar)
 
     def __init_notebook(self, mother_frame):
-        '''The notebook is the root widget for tabs or riders.
-
-        Args:
-            mother_frame (ttk.Frame): A frame to place the notebook in.
-        '''
+        '''The notebook is the root widget for tabs or riders.'''
         self.nb = ttk.Notebook(mother_frame)
         side_='right'
         if self.p['compact_layout']:
@@ -250,8 +255,8 @@ class OpenPivGui(tk.Tk):
                    command=self.destroy).pack(
                        side='left', fill='x')
         ttk.Button(f,
-                   text='select files',
-                   command=self.select_image_files).pack(
+                   text='open directory',
+                   command=self.open_directory).pack(
                        side='left', fill='x')
         ttk.Button(f,
                    text='start processing',
@@ -296,7 +301,7 @@ class OpenPivGui(tk.Tk):
         f.pack(side='top', fill='x')
     
     def user_function(self):
-        '''User function.'''
+        '''Executes user function.'''
         self.get_settings()
         exec(self.p['user_func_def'])
 
@@ -338,12 +343,60 @@ class OpenPivGui(tk.Tk):
         if len(settings) > 0:
             self.p.load_settings(settings)
             self.set_settings()
+    
+    def load_pandas(self, fname):
+        '''Load files in a pandas data frame.
 
+        On the rider named General, the parameters for loading
+        the data frames can be specified.
+        No parameters have to be set for image processing. 
+        
+        Parameters
+        ----------
+        fname : 
+            A filename.
+        
+        Returns
+        -------
+        pandas.DataFrame :
+            In case of an error, the errormessage is returned (str).
+        '''
+
+        sep = self.p['sep']
+        if sep == 'tab': sep = '\t'
+        if sep == 'space': sep = ' '
+        
+        ext = fname.split('.')[-1]
+        if ext in ['txt', 'dat', 'jvc', 'vec', 'csv']:
+            if self.p['load_settings'] == True:
+                if self.p['header'] == True:
+                    data = pd.read_csv(fname, 
+                                   decimal = self.p['decimal'],
+                                   skiprows = int(self.p['skiprows']),
+                                   sep = sep)
+                elif self.p['header'] == False:
+                    data = pd.read_csv(fname, 
+                                   decimal = self.p['decimal'],
+                                   skiprows = int(self.p['skiprows']),
+                                   sep = sep,
+                                   header = 0,
+                                   names = self.p['header_names'].split(','))
+            else:
+                data = pd.read_csv(fname, 
+                                   decimal = ',', 
+                                   skiprows = 0, 
+                                   sep = '\t')
+        else: 
+            data = 'File could not be read. Possibly it is an image file.'
+        return(data)
+    
     def __init_listbox(self, key):
         '''Creates an interactive list of filenames.
 
-        Args:
-            key (str): Key of a settings object of type str[].
+        Parameters
+        ----------
+        key : str
+            Key of a settings object.
         '''
         # root widget
         f = ttk.Frame(self)
@@ -378,20 +431,24 @@ class OpenPivGui(tk.Tk):
     def get_filelistbox(self):
         '''Return a handle to the file list widget.
 
-        Returns:
-            A tkinter.Listbox object.
+        Returns
+        -------
+        tkinter.Listbox
+            A handle to the listbox widget holding the filenames
         '''
         return(self.lb)
 
     def navigate(self, direction):
         '''Navigate through processing steps.
 
-        Args:
-            direction (str): »back« or »forward«.
-
         Display a filtered list of files of the current
         directory. This function cycles through the filters
         specified by the key 'navi_pattern' in the settings object.
+
+        Parameters
+        ----------
+        direction : str
+            'back' or 'forward'.
         '''        
         pattern_lst = str2list(self.p['navi_pattern'])
         dirname = os.path.dirname(self.p['fnames'][0])
@@ -418,12 +475,17 @@ class OpenPivGui(tk.Tk):
     def file_filter(self, files, pattern):
         '''Filter a list of files to  match a pattern.
 
-        Args:
-            files (str[]): A list of pathnames.
-            pattern (str): A regular expression for filtering the list.
+        Parameters
+        ----------
+        files : str[]
+            A list of pathnames.
+        pattern : str
+            A regular expression for filtering the list.
 
-        Returns:
-            str[]: List items that match pattern.
+        Returns
+        -------
+        str[]
+            List items that match the pattern.
         '''
         filtered = []
         print('file filter: ' + pattern)
@@ -470,6 +532,8 @@ class OpenPivGui(tk.Tk):
         else:
             self.get_settings()
             self.show(self.p['fnames'][index])
+            if self.p['data_information'] == True:
+                self.show_informations(self.p['fnames'][index])
 
     def __init_entry(self, key):
         '''Creates a label and an entry in a frame.
@@ -479,8 +543,10 @@ class OpenPivGui(tk.Tk):
         in the parameter object. The help string in the parameter object
         is used for creating a tooltip.
 
-        Args:
-            key (str): Key of a parameter obj.
+        Parameter
+        ---------
+        key : str
+            Key of a parameter obj.
         '''
         f = ttk.Frame(self.set_frame[-1])
         f.pack(fill='x')
@@ -517,24 +583,32 @@ class OpenPivGui(tk.Tk):
         CreateToolTip(cb, self.p.help[key])
         cb.pack(side='left')
 
-    def log(self, timestamp=False, text=None, group=None):
+    def log(self, columninformation = None, timestamp=False, text=None, 
+            group=None):
         ''' Add an entry to the lab-book.
 
         The first initialized text-area is assumed to be the lab-book.
         It is internally accessible by self.ta[0].
 
-        Kwargs:
-            timestamp (bool): Print current time.
-                              Pattern: yyyy-mm-dd hh:mm:ss.
-                              (default False)
-            text (str): Print a text, a linebreak is appended. 
-                        (default None)
-            group (int): Print group of parameters.
-                         (e.g. OpenPivParams.PIVPROC)
+        Parameters
+        ----------
+        timestamp : bool
+            Print current time.
+            Pattern: yyyy-mm-dd hh:mm:ss.
+            (default: False)
+        text : str
+            Print a text, a linebreak is appended. 
+            (default None)
+        group : int
+            Print group of parameters.
+            (e.g. OpenPivParams.PIVPROC)
+        columninformation : list
+            Print column information of the selected file.
 
-        Example:
-            log(text='processing parameters:', 
-                group=OpenPivParams.POSTPROC)
+        Example
+        -------
+        log(text='processing parameters:', 
+            group=OpenPivParams.POSTPROC)
         '''
         if text is not None:
             self.ta[0].insert(tk.END, text + '\n')
@@ -550,6 +624,22 @@ class OpenPivGui(tk.Tk):
                 if group < self.p.index[key] < group+1000:
                     s = key + ': ' + str(self.p[key])
                     self.log(text=s)
+        if columninformation is not None:
+            self.ta[0].insert(tk.END, str(columninformation) + '\n')
+                    
+    def show_informations(self, fname):
+        ''' Shows the column names of the chosen file in the labbook.
+        
+        Parameters
+        ----------
+        fname : str
+            A filename.
+        '''
+        data = self.load_pandas(fname)
+        if isinstance(data, str) == True:
+            self.log(text = data)
+        else:
+            self.log(columninformation = list(data.columns.values))
 
     def get_settings(self):
         '''Copy widget variables to the parameter object.'''
@@ -578,53 +668,69 @@ class OpenPivGui(tk.Tk):
             self.p['fnames'] = list(files)
             self.tkvars['fnames'].set(self.p['fnames'])
 
+    def open_directory(self):
+        '''Show a dialog for opening a directory.'''
+        dir = filedialog.askdirectory()
+        if len(dir) > 0:
+            files = [dir + os.sep + file for file in os.listdir(dir)]
+            self.p['fnames'] = list(files)
+            self.tkvars['fnames'].set(self.p['fnames'])
+        self.navigate('back')
 
     def show(self, fname):
         '''Display a file.
 
         This method distinguishes vector data (file extensions
-        txt, dat, jvc and vec) and images (all other file extensions).
+        txt, dat, jvc,vec and csv) and images (all other file extensions).
 
-        Args:
-            fname (str): A filename.
+        Parameters
+        ----------
+        fname : str
+            A filename.
         '''
         ext = fname.split('.')[-1]
         self.fig.clear()
-        if ext in ['txt', 'dat', 'jvc', 'vec']:
-            if self.p['plot_type'] == 'histogram':
-                histogram(
-                    fname,
-                    self.fig,
-                    quantity=self.p['histogram_quantity'],
-                    bins=self.p['histogram_bins'],
-                    log_y=self.p['histrogram_log_scale']
-                )
-            elif self.p['plot_type'] == 'profiles':
-                profiles(fname,
+        data = self.load_pandas(fname)
+        if ext in ['txt', 'dat', 'jvc', 'vec','csv']:
+            if self.p['pandas_utility'] == True:
+                pandas_plot(data, self.p, self.fig)
+            else:
+                if self.p['plot_type'] == 'histogram':
+                    histogram(
+                        fname,
+                        self.fig,
+                        quantity=self.p['histogram_quantity'],
+                        bins=self.p['histogram_bins'],
+                        log_y=self.p['histrogram_log_scale']
+                    )
+                elif self.p['plot_type'] == 'profiles':
+                    profiles(fname,
                          self.fig,
                          orientation=self.p['profiles_orientation']
-                )
-            elif self.p['plot_type'] == 'scatter':
-                scatter(fname,
+                    )
+                elif self.p['plot_type'] == 'scatter':
+                    scatter(fname,
                         self.fig
-                )
-            else:
-                vector(
-                    fname,
-                    self.fig,
-                    invert_yaxis=self.p['invert_yaxis'],
-                    scale=self.p['vec_scale'],
-                    width=self.p['vec_width'])
+                    )
+                else:
+                    vector(
+                        fname,
+                        self.fig,
+                        invert_yaxis=self.p['invert_yaxis'],
+                        scale=self.p['vec_scale'],
+                        width=self.p['vec_width']
+                    )
         else:
             self.show_img(fname)
         self.fig.canvas.draw()
 
-
     def show_img(self, fname):
         '''Display an image.
 
-        Args:
-            fname (str): Pathname of an image file.
+        Parameters
+        ----------
+        fname : str
+            Pathname of an image file.
         '''
         img = piv_tls.imread(fname)
         print('image data type: {}'.format(img.dtype))
