@@ -167,6 +167,33 @@ class OpenPivParams():
                  'Regular expression patterns for filtering the files ' +
                  'in the current directory. Use the back and forward ' +
                  'buttons to apply a different filter.'],
+            'load_settings':
+                [1050, 'bool', False, None,
+                 'settings for using pandas',
+                 'Individual settings ' +
+                 'for loading files using pandas.'],
+            'skiprows':
+                [1051, 'str', '0', None,
+                 'skip rows', 
+                 'Number of rows skipped at the beginning of the file.'],
+            'decimal':
+                [1052, 'str', '.', None,
+                 'decimal separator', 
+                 'Decimal separator for floating point numbers.'],
+            'sep':
+                [1053, 'str', 'tab', (',', ';', 'space', 'tab'),
+                 'column separator',
+                 'Column separator.'],
+            'header':
+                [1054, 'bool', False, None,
+                 'read header', 
+                 'Read header. ' + 
+                 'If chosen, first line will be interpreted as the header'],
+            'header_names':
+                [1055, 'str', 'x,y,vx,vy,sig2noise', None,
+                 'specify own header names',
+                 'Specify comma separated list of column names.' +
+                 'Example: x,y,vx,vy,sig2noise'],
             # preprocessing
             'preproc':
                 [2000, None, None, None,
@@ -338,6 +365,45 @@ class OpenPivParams():
                 [8210, 'str', 'vertical', ('vertical', 'horizontal'),
                  'profiles orientation',
                  'Plot v_y over x (horizontal) or v_x over y (vertical).'],
+            'pandas_utility':
+                [8300, 'bool', False, None,
+                 'Use pandas plot utility.',
+                 'If chosen, plots will be generated with pandas.'],
+            'pandas_plot_type':
+                [8310, 'str', 'density',
+                 ('line','bar', 'barh', 'hist', 'box',
+                  'density', 'area', 'scatter'),
+                 'plot-type', 'Choose plot-type. For further information ' +
+                 'refer to pandas.DataFrame.plot().'],
+            'x_data':
+                [8320, 'str', 'vx', None, 'column name for x-data',
+                 'column name for x-data. If unknown watch labbook entry.'],
+            'y_data':
+                [8330, 'str', 'vy', None, 'column name for y-data',
+                 'column name for y-data. If unknown watch labbook entry.' +
+                 ' For histogram only y_data are needed.'],
+            'plot_bins':
+                [8475, 'str', '10', None, 'number of bins', 'number of bins.' +
+                 ' This box is only used for plotting type scatter.'],
+            'plot_title':
+                [8340, 'str', 'Title', None, 'diagram title', 'diagram title.'],
+            'plot_grid':
+                [8450, 'bool', True, None, 'grid', 
+                 'adds a grid to the diagram.'],
+            'plot_legend':
+                [8460, 'bool', True, None, 'legend', 
+                 'adds a legend to the diagram.'],
+            'plot_scaling': 
+                [8470, 'str', 'None', ('None', 'logx', 'logy', 'loglog'),
+                 'axis scaling', 'scales the axes. logarithm scaling x-axis' +
+                 ' --> logx; logarithm scaling y-axis --> logy; ' +
+                 'logarithm scaling both axes --> loglog.'],
+            'plot_xlim':
+                [8480, 'str', '', None, 'limits for the x-axis', 
+                 'For implementation use (lower_limit, upper_limit).'],
+            'plot_ylim':
+                [8485, 'str', '', None, 'limits for the y-axis',
+                 'For implementation use (lower_limit, upper_limit).'],
             # lab-book
             'lab_book':
                 [9000, None, None, None,
@@ -349,6 +415,10 @@ class OpenPivParams():
                  None,
                  None,
                  None],
+            'data_information':
+                [9020, 'bool', False, None, 'log column information', 
+                 'shows column names, if you choose a file at the ' + 
+                 'right side.'],
             # user-function
             'user_func':
                 [10000, None, None, None,
