@@ -22,6 +22,7 @@ __email__= 'vennemann@fh-muenster.de'
 import argparse
 
 import numpy as np
+import pandas as pd
 import matplotlib.pyplot as plt
 from matplotlib.figure import Figure
 
@@ -31,15 +32,18 @@ def histogram(fname, figure, quantity, bins, log_y):
 
     Plots an histogram of the specified quantity.
 
-    Args:
-        fname (str): A filename containing vector data.
-        figure (matplotlib.figure.Figure): 
-            An (empty) Figure object.
-        quantity (str): Either v (abs v), 
-                               v_x (x-component) or 
-                               v_y (y-component).
-        bins (int): Number of bins (bars) in the histogram.
-        log_scale (boolean): Use logaritmic vertical axis.
+    Parameters
+    ----------
+    fname : str
+        A filename containing vector data.
+    figure : matplotlib.figure.Figure
+        An (empty) Figure object.
+    quantity : str
+        Either v (abs v), v_x (x-component) or v_y (y-component).
+    bins : int
+         Number of bins (bars) in the histogram.
+    log_scale : boolean
+        Use logaritmic vertical axis.
     '''
     data = np.loadtxt(fname)
     if quantity == 'v':
@@ -64,13 +68,15 @@ def profiles(fname, figure, orientation):
 
     Line plots of the velocity component specified.
 
-    Args:
-        fname (str): A filename containing vector data.
-        figure (matplotlib.figure.Figure): 
-            An (empty) Figure object.
-        orientation (str): 
-            horizontal: Plot v_y over x.
-            vertical: Plot v_x over y.
+    Parameters
+    ----------
+    fname : str
+        A filename containing vector data.
+    figure : matplotlib.figure.Figure 
+        An (empty) Figure object.
+    orientation : str 
+        horizontal: Plot v_y over x.
+        vertical: Plot v_x over y.
     '''
     data = np.loadtxt(fname)
     dim_x, dim_y = get_dim(data)
@@ -99,10 +105,12 @@ def scatter(fname, figure):
 
     Plots v_y over v_x.
 
-    Args:
-        fname (str): Name of a file containing vector data.
-        figure (matplotlib.figure.Figure): 
-            An (empty) Figure object.
+    Parameters
+    ----------
+    fname : str
+        Name of a file containing vector data.
+    figure : matplotlib.figure.Figure 
+        An (empty) Figure object.
     '''
     data = np.loadtxt(fname)
     v_x = data[:,2]
@@ -116,10 +124,12 @@ def scatter(fname, figure):
 def vector(fname, figure, invert_yaxis=True, **kw):
     '''Display a vector plot.
 
-    Args:
-        fname (str): Pathname of a text file containing vector data.
-        figure (matplotlib.figure.Figure): 
-            An (empty) Figure object.
+    Parameters
+    ----------
+    fname : str
+        Pathname of a text file containing vector data.
+    figure : matplotlib.figure.Figure 
+        An (empty) Figure object.
     '''
     data = np.loadtxt(fname)
     invalid = data[:, 4].astype('bool')
@@ -143,8 +153,79 @@ def vector(fname, figure, invert_yaxis=True, **kw):
             ax.invert_yaxis()
     ax.set_xlabel('x position')
     ax.set_ylabel('y position')
+    
+def pandas_plot(data, parameter, figure):
+    '''Display a plot with the pandas plot utility.
+    
+    Parameters
+    ----------
+    data : pandas.DataFrame
+        Data to plot.
+    parameter : openpivgui.OpenPivParams
+        Parameter-object.
+    figure : matplotlib.figure.Figure
+        An (empty) figure.
 
+    Returns
+    -------
+    None.
 
+    '''
+    if parameter['plot_scaling'] == 'None':
+        logx, logy, loglog = False, False, False
+    elif parameter['plot_scaling'] == 'logx':
+        logx, logy, loglog = True, False, False
+    elif parameter['plot_scaling'] == 'logy':
+        logx, logy, loglog = False, True, False
+    elif parameter['plot_scaling'] == 'loglog':
+        logx, logy, loglog = False, False, True
+        
+    ax = figure.add_subplot(111)
+    
+    xlim = None
+    ylim = None
+    
+    try:
+        xlim = (int(list(parameter['plot_xlim'].split(','))[0]),
+            int(list(parameter['plot_xlim'].split(','))[1]))
+    except:       
+        print('No Values or wrong syntax for x-axis limitation.')
+    try:
+        ylim = (int(list(parameter['plot_ylim'].split(','))[0]),
+            int(list(parameter['plot_ylim'].split(','))[1]))
+    except:
+        print('No Values or wrong syntax for y-axis limitation.')
+    
+    for i in list(data.columns.values):
+        data[i] = data[i].astype(float)
+        
+    if parameter['pandas_plot_type'] == 'hist':
+        data_hist = data[parameter['y_data']]
+        data_hist.plot.hist(by = parameter['y_data'],
+                       bins = int(parameter['plot_bins']), 
+                       title = parameter['plot_title'],
+                       grid = parameter['plot_grid'],
+                       legend = parameter['plot_legend'],
+                       logx = logx,
+                       logy = logy,
+                       loglog = loglog,
+                       xlim = xlim,
+                       ylim = ylim,
+                       ax = ax)
+    else:
+        data.plot(x = parameter['x_data'], 
+              y = parameter['y_data'], 
+              kind = parameter['pandas_plot_type'], 
+              title = parameter['plot_title'], 
+              grid = parameter['plot_grid'], 
+              legend = parameter['plot_legend'],
+              logx = logx, 
+              logy = logy , 
+              loglog = loglog, 
+              xlim = xlim,
+              ylim = ylim,
+              ax = ax)
+    
 def get_dim(array):
     '''Computes dimension of vector data.
 
@@ -155,11 +236,15 @@ def get_dim(array):
     16 32 4.2 3.5
     32 32 4.5 3.2
 
-    Args:
-        array (np.array): Flat numpy array.
+    Parameters
+    ----------
+    array : np.array
+        Flat numpy array.
 
-    Returns:
-        (tuple): Dimension of the vector field (x, y).
+    Returns
+    -------
+    tuple
+        Dimension of the vector field (x, y).
     '''
     return(len(set(array[:, 0])),
            len(set(array[:, 1])))
